# Vicoa - Vibe Code Anywhere 🚀

<div align="center">

**Coding agents in your pocket.**

</div>

<div align="center">

[📱 **Download iOS App**](https://apps.apple.com/us/app/id6751626168) • [🌐 **Try Web Dashboard**](https://vibecodeanywhere.com)

</div>

---

## 🚀 Quick Start

1. Install command line tool
```bash
# Install Vicoa
pip install vicoa

# Start a Claude Code session that's synced between terminal, web, and mobile
vicoa
```

2. Create an account when prompted

3. Return to your terminal to interact with Claude Code. 

You can view Claude Code session from the [web dashboard](https://vibecodeanywhere.com) or the [mobile app](https://apps.apple.com/us/app/id6751626168).

## 💡 What is Vicoa?

Vicoa means "<u>Vi</u>be <u>Co</u>de <u>A</u>nywhere". It lets you use Claude Code on any device. Start coding on your laptop, switch easily to mobile or web, get alerts when your AI agent needs input, and approve changes with one tap.
